package dao;

import java.util.HashMap;

import valueObject.RadioValueObject;


/**
 * Data manipulation for RadioValueObject.
 * 
 * @author Olivier Garrouste.
 * Creation date: 2006-02-25.
 */
public class RadioDao {

	// Sequence.
	private static int id;

	// Table of all the radio <radio_id,RadioValueObject>.
	private static HashMap<Integer,RadioValueObject> hashmapRadio;

	/**
	 * Clear the sequence.
	 */
	public static synchronized void clear() {
		id = 1;
		hashmapRadio = new HashMap<Integer,RadioValueObject>();
	}

	/**
	 * Return the next unique radio identifier.
	 * @return The next unique radio identifier
	 */
	public static synchronized int getNextId() {
		return id++;
	}

	/**
	 * Add the given radio the global radio list.
	 * 
	 * @param radio A RadioValueObject.
	 */
	public static void insert(RadioValueObject radio) {
		hashmapRadio.put(new Integer(radio.getId()), radio);
	}

	/**
	 * Return the radio of the given id. If the radio does not exists, return null.
	 * 
	 * @param id The radio identifier (Integer).
	 * @return A RadioValueObject or null if it does not exists.
	 */
	public static RadioValueObject getById(Integer id) {
		return hashmapRadio.get(id);
	}
}
