package dao;

import java.util.ArrayList;
import java.util.HashMap;

import valueObject.SubgenreValueObject;

public class SubgenreDao {

	// Sequence.
	private static int code;

	// Subgenres <code,SubgenreValueObject>.
	private static HashMap<String,SubgenreValueObject> hashmapCode;

	// Database initialization.
	static {
		clear();
	}
	
	/**
	 * Clear the sequence.
	 */
	public static synchronized void clear() {
		code = 1;
		hashmapCode = new HashMap<String,SubgenreValueObject>();
	}

	/**
	 * Return the next unique genre identifier.
	 * @return The next unique genre identifier
	 */
	public static synchronized int getNextCode() {
		return code++;
	}

	/**
	 * Add a genre into the Genre database, replace any existing one.
	 * 
	 * @param genre A GenreValueObject.
	 */
	public static synchronized void insert(SubgenreValueObject subgenre) {
	
		// Nothing to store, exit.
		if ( subgenre == null )
			return;

		// Store.
		hashmapCode.put(subgenre.getCode(), subgenre);
	}

	/**
	 * Return the subgenre of the given code.
	 * 
	 * @param code
	 * @return A SubgenreValueObject or null if nothing corresponds to that code.
	 */
	public static SubgenreValueObject getByCode(String StrCode) {
		
		return hashmapCode.get(StrCode);
	}

	/**
	 * Return the SubgenreValueObject of the given name from the list. If it does not
	 * exists return null.
	 * 
	 * @param name The name of the subgenre requested.
	 * @return A GenreValueObject or null if it does not exists.
	 */
	public static SubgenreValueObject getByName(ArrayList<SubgenreValueObject> subgenreList, String subgenreName) {
		SubgenreValueObject subgenre;
		int nb, i;

		if ( subgenreName == null )
			return null;

		nb = subgenreList.size();

		for ( i=0 ; i<nb ; i++ ) {
			subgenre = subgenreList.get(i);

			if ( subgenreName.equals(subgenre.getName()))
				return subgenre;
		}

		return null;
	}

}
