package proxy;

import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;

import org.apache.log4j.Logger;

import valueObject.ProxyRequestValueObject;

/**
 * Title: Proxy server
 * Description: send a client request to a server asynchronously.
 * 
 * @author Olivier Garrouste
 * @version 1.1
 */
public class ProxyToServerThread extends Thread {

	private static final Logger logger = Logger.getLogger(ProxyToServerThread.class);

	private OutputStream serverOut;
	private String clientRequest;
	private static int threadNumber = 0;


	/**
	 * Send the client request to the server asynchronously. Get the request from the 
	 * ProxyRequestValueObject and send it to the serverOutputStream
	 * 
	 * @param proxyRequest A ProxyRequestValueObject.
	 */
	public ProxyToServerThread(ProxyRequestValueObject proxyRequest) {
		// Name the thread.
		super("ProxyToServerThread-" + (threadNumber++));

		this.serverOut = proxyRequest.getServerOutputStream();
		this.clientRequest = proxyRequest.getRequest();
		start();
	}

	public void run() {
		logger.debug("Start of thread.");

		try {
			PrintWriter out = new PrintWriter(new OutputStreamWriter(serverOut));

			//clientRequest += "Icy-MetaData:1\r\n";
			out.print(clientRequest);

			// Send a blank line (means end of request).
			out.println();
			out.flush();

			logger.debug("Request sent to server = \"" + clientRequest + "\"");
		}
		catch (Exception e) {
			logger.error("ERROR : " + e.toString(), e);
		}
		logger.debug("End of thread.");
	}
}
