package proxy.streamHandler;

import java.io.InputStream;
import java.io.OutputStream;

import org.apache.log4j.Logger;

import util.Net;
import valueObject.ProxyRequestValueObject;

/**
 * Title: Proxy server
 * Description: Process data exchange between client and server. Does not filter
 * anything, data is forwarded without modification.
 * 
 * @author Olivier Garrouste
 * Creation date: 2006-02-25
 */
public class DefaultStreamHandler {

	private static final Logger logger = Logger.getLogger(DefaultStreamHandler.class);

	/**
	 * Default stream handler: direct copy from server to client.
	 * 
	 * @param proxyRequest A valid ProxyRequest object.
	 * @param startData A buffer containing the data to send to the client before
	 * transfering the server data. Typically, this is the extra data read by the
	 * protocol analyzer that need to be sent to the client. It may be null if no data
	 * is to be sent.
	 */
	public static void process(ProxyRequestValueObject proxyRequest, byte[] startData) {
		OutputStream clientOut;
		InputStream serverIn;

		clientOut = proxyRequest.getClientOutputStream();
		serverIn = proxyRequest.getServerInputStream();

		// Send the chunk of data read by the protocol analyzer to the net-tune client.
		if ( startData != null )
			Net.write(startData, clientOut);

		logger.debug("Start reading from server and sending to client.");

		// Read response from server and forward to client.
		Net.transfert(serverIn, clientOut);
		logger.debug("End reading from server and sending to client.");
	}

}
