package valueObject;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.TreeSet;

/**
 * Container holding code from genre or subgenre.
 * 
 * @author Olivier Garrouste
 */
public abstract class AbstractGenreValueObject {

	protected String name;

	// Genre code "00.000".
	protected String code;

	/**
	 * List of radio associated with this genre (RadioValueObject). The radio listed
	 * here are not associaed with a subgenre.
	 */
	protected ArrayList<RadioValueObject> radioList;

	/**
	 * Class used to sort returned radio list.
	 */
	private class AbstractGenreComparator implements Comparator<RadioValueObject> {

		public int compare(RadioValueObject r1, RadioValueObject r2) {
			return r1.getName().compareTo(r2.getName());
		}
	}


	/**
	 * Constructor.
	 */
	public AbstractGenreValueObject() {
		radioList = new ArrayList<RadioValueObject>();
	}

	/**
	 * @return Returns the name.
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name The name to set.
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return Returns the code.
	 */
	public String getCode() {
		return code;
	}	

	/**
	 * @return Returns the radioList sorted by radio name.
	 */
	public RadioValueObject[] getRadioList() {
		TreeSet<RadioValueObject> treeSet;

		treeSet = new TreeSet<RadioValueObject>(new AbstractGenreComparator());
		treeSet.addAll(radioList);

		return treeSet.toArray(new RadioValueObject[0]);
	}
}
