package valueObject;

import java.util.ArrayList;

import util.Formater;
import dao.GenreDao;

/**
 * Container holding data for a Genre.
 * 
 * @author Olivier Garrouste
 * Creation date: 2006-02-25.
 */
public class GenreValueObject extends AbstractGenreValueObject {

	// List of subgenres (SubgenreValueObject).
	private ArrayList<SubgenreValueObject> subgenreList;


	/**
	 * Constructor.
	 */
	public GenreValueObject() {
		super();
		code = Formater.intToStr2(GenreDao.getNextCode()) + ".000";
		subgenreList = new ArrayList<SubgenreValueObject>();
	}

	/**
	 * @return Returns the subgenre.
	 */
	public ArrayList<SubgenreValueObject> getSubgenreList() {
		return subgenreList;
	}

	/**
	 * Add a subgenre to the list of subgenres of the object.
	 * @param subgenre The subgenre to add.
	 */
	public void addSubgenre(SubgenreValueObject subgenre) {
		subgenreList.add(subgenre);
	}

	/**
	 * Add a new radio to this genre.
	 * @param radio The radioList to add.
	 */
	public void addRadio(RadioValueObject radio) {
		radioList.add(radio);
	}

	/**
	 * Display this object content.
	 */
	public String toString() {
		StringBuilder str;

		str = new StringBuilder();
		str.append("GenreValueObject[code=\"").append(code);
		str.append("\", name=\"").append(name);
		str.append("\", subgenreList=").append(subgenreList);
		str.append(", radioList=").append(radioList).append("]");

		return str.toString();
	}
}
