package valueObject;

import java.util.HashMap;

import util.Constant.Protocol;

/**
 * An object holding a response (only the first bytes) from a server.
 * 
 * @author Olivier Garrouste.
 * Creation date: 2006-09-02
 */
public class ResponseValueObject {

	/**
	 * Raw data of the response.
	 */
	private byte data[];

	/**
	 * Protocol identifier, see Constants.Protocol.* .
	 */
	private Protocol idProtocol;

	/**
	 * Status code of the response. Only valid when protocol is not PROTOCOL_UNKNOWN.
	 */
	private int statusCode;

	/**
	 * Header fields <header-tag, value>.
	 */
	private HashMap<String,String> headersHashmap;


	/**
	 * Constructor.
	 */
	public ResponseValueObject() {
		headersHashmap = new HashMap<String,String>();
	}

	/**
	 * @return The raw data of the response.
	 */
	public byte[] getData() {
		return data;
	}

	/**
	 * @param data The data to set.
	 */
	public void setData(byte[] data) {
		this.data = data;
	}

	/**
	 * @return Returns the idProtocol.
	 */
	public Protocol getIdProtocol() {
		return idProtocol;
	}

	/**
	 * @param idProtocol The idProtocol to set.
	 */
	public void setIdProtocol(Protocol idProtocol) {
		this.idProtocol = idProtocol;
	}

	/**
	 * @return Returns the statusCode.
	 */
	public int getStatusCode() {
		return statusCode;
	}

	/**
	 * @param statusCode The statusCode to set.
	 */
	public void setStatusCode(int statusCode) {
		this.statusCode = statusCode;
	}

	/**
	 * Returns content of the specified header.
	 * 
	 * @param name The header field to retrieve.
	 * @return The header content or null if it does not exists.
	 */
	public String getHeader(String name) {
		return (String)  headersHashmap.get(name);
	}

	/**
	 * Set the header pair (name,value).
	 * 
	 * @param name
	 * @param Value
	 */
	public void setHeader(String name, String value) {
		headersHashmap.put(name, value);
	}
}
